@@ -8,11 +8,8 @@ from django.utils import timezone
 from django.db.utils import IntegrityError
 from django.db import transaction
 
-try:
-    from django_redis import get_redis_connection
-except ImportError:
-    get_redis_connection = None
 
+from django_redis import get_redis_connection
 from django_apiview.views import apiview
 
 from . import settings
@@ -31,8 +28,6 @@ class DjangoDbLockServer(object):
     def get_redis_cache_enabled(self):
         if not self.use_redis_cache:
             return False
-        if not get_redis_connection:
-            return False
         try:
             db = get_redis_connection(self.redis_cache_name)
             return db.ping()
@@ -40,7 +35,7 @@ class DjangoDbLockServer(object):
             return False
 
     def get_redis_connection(self):
-        if self.enable_redis_cache:
+        if self.redis_cache_enabled:
             return get_redis_connection(self.redis_cache_name)
         else:
             return None
@@ -52,7 +47,7 @@ class DjangoDbLockServer(object):
         try:
             return self._clear_expired_locks()
         except Exception as error:
-            logger.exception("clear_expired_locks failed: error_message={}".format(error))
+            logger.exception("clear_expired_locks failed: error_message={0}".format(error))
 
     def _clear_expired_locks(self):
         now_time = timezone.now()
@@ -67,13 +62,15 @@ class DjangoDbLockServer(object):
         if not result1:
             return result1
         result2 = self.acquire_lock_in_database(lock_name, worker_name, expire_at)
+        if not result2:
+            self.release_lock_in_redis(lock_name, worker_name)
         return result2
 
     def acquire_lock_in_redis(self, lock_name, worker_name, expire_at):
         try:
             return self._acquire_lock_in_redis(lock_name, worker_name, expire_at)
         except Exception as error:
-            logger.exception("acquire_lock_in_redis failed, lock_name={} worker_name={} expire_at={} error_message={0}".format(lock_name, worker_name, expire_at, error))
+            logger.exception("acquire_lock_in_redis failed, lock_name={0} worker_name={1} expire_at={2} error_message={3}".format(lock_name, worker_name, expire_at, error))
             return False
 
     def _acquire_lock_in_redis(self, lock_name, worker_name, expire_at):
@@ -90,7 +87,7 @@ class DjangoDbLockServer(object):
         try:
             return self._acquire_lock_in_database(lock_name, worker_name, expire_at)
         except Exception as error:
-            logger.exception("acquire_lock_in_database failed, lock_name={} worker_name={} error_message={0}".format(lock_name, worker_name, error))
+            logger.exception("acquire_lock_in_database failed, lock_name={0} worker_name={1} error_message={2}".format(lock_name, worker_name, error))
             return False
 
     def _acquire_lock_in_database(self, lock_name, worker_name, expire_at): 
@@ -115,8 +112,8 @@ class DjangoDbLockServer(object):
     def release_lock_in_redis(self, lock_name, worker_name):
         try:
             return self._release_lock_in_redis(lock_name, worker_name)
-        except Exception:
-            logger.exception("release_lock_in_redis failed: lock_name={} worker_name={} error_message={}".format(lock_name, worker_name, error))
+        except Exception as error:
+            logger.exception("release_lock_in_redis failed: lock_name={0} worker_name={1} error_message={2}".format(lock_name, worker_name, error))
             return False
 
     def _release_lock_in_redis(self, lock_name, worker_name):
@@ -132,7 +129,7 @@ class DjangoDbLockServer(object):
         try:
             return self._release_lock_in_database(lock_name, worker_name)
         except Exception as error:
-            logger.exception("release_lock_in_database failed: lock_name={} worker_name={} error_message={}".format(lock_name, worker_name, error))
+            logger.exception("release_lock_in_database failed: lock_name={0} worker_name={1} error_message={2}".format(lock_name, worker_name, error))
             return False
 
     def _release_lock_in_database(self, lock_name, worker_name):
